==> jc-1.4.0.tar.gz: java/text/RuleBasedCollator__24CollationSorter.h <==
// final class java.text.RuleBasedCollator$CollationSorter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c548fa6aa0210e9c java_text_RuleBasedCollator__24CollationSorter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_RuleBasedCollator__24CollationSorter_H_
#define _JC_java_text_RuleBasedCollator__24CollationSorter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$sub_refs	_jc_java_text_RuleBasedCollator__24CollationSorter$sub_refs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$sub_nonrefs	_jc_java_text_RuleBasedCollator__24CollationSorter$sub_nonrefs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$refs	_jc_java_text_RuleBasedCollator__24CollationSorter$refs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$nonrefs	_jc_java_text_RuleBasedCollator__24CollationSorter$nonrefs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$object	_jc_java_text_RuleBasedCollator__24CollationSorter$object;

typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$fields_struct	_jc_java_text_RuleBasedCollator__24CollationSorter$fields_struct;
typedef const struct _jc_java_text_RuleBasedCollator__24CollationSorter$vmethods	_jc_java_text_RuleBasedCollator__24CollationSorter$vmethods;
typedef const struct _jc_java_text_RuleBasedCollator__24CollationSorter$vtable	_jc_java_text_RuleBasedCollator__24CollationSorter$vtable;
typedef const struct _jc_java_text_RuleBasedCollator__24CollationSorter$vtype	_jc_java_text_RuleBasedCollator__24CollationSorter$vtype;

// Class fields structure
struct _jc_java_text_RuleBasedCollator__24CollationSorter$fields_struct {
	jint	EQUAL;
	jint	GREATERP;
	jint	GREATERS;
	jint	GREATERT;
	jint	INVERSE__5fSECONDARY;
	jint	RESET;
};
extern _jc_java_text_RuleBasedCollator__24CollationSorter$fields_struct _jc_java_text_RuleBasedCollator__24CollationSorter$class_fields;

// Constructors
extern void _jc_java_text_RuleBasedCollator__24CollationSorter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_text_RuleBasedCollator__24CollationSorter$object *);

// Virtual methods structure
struct _jc_java_text_RuleBasedCollator__24CollationSorter$vmethods {
};

// Vtable
struct _jc_java_text_RuleBasedCollator__24CollationSorter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_RuleBasedCollator__24CollationSorter$vmethods	java_text_RuleBasedCollator__24CollationSorter;
};

// Vtype
struct _jc_java_text_RuleBasedCollator__24CollationSorter$vtype {
	_jc_type			type;
	_jc_java_text_RuleBasedCollator__24CollationSorter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_RuleBasedCollator__24CollationSorter$sub_refs {
	struct _jc_java_lang_String$object	*textElement;
	struct _jc_java_lang_String$object	*expansionOrdering;
};

// Reference instance fields (object)
struct _jc_java_text_RuleBasedCollator__24CollationSorter$refs {
    _jc_java_text_RuleBasedCollator__24CollationSorter$sub_refs	java_text_RuleBasedCollator__24CollationSorter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_RuleBasedCollator__24CollationSorter$sub_nonrefs {
	jint	comparisonType;
	jint	hashText;
	jint	offset;
	jboolean	ignore;
};

// Non-reference instance fields (object)
struct _jc_java_text_RuleBasedCollator__24CollationSorter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_RuleBasedCollator__24CollationSorter$sub_nonrefs	java_text_RuleBasedCollator__24CollationSorter;
};

// Object instance structure
struct _jc_java_text_RuleBasedCollator__24CollationSorter$object {
	_jc_java_text_RuleBasedCollator__24CollationSorter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_RuleBasedCollator__24CollationSorter$vtype	*vtype;
	_jc_java_text_RuleBasedCollator__24CollationSorter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_RuleBasedCollator__24CollationSorter$vtype _jc_java_text_RuleBasedCollator__24CollationSorter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_RuleBasedCollator__24CollationSorter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_RuleBasedCollator__24CollationSorter$class_object;

#endif	/* _JC_java_text_RuleBasedCollator__24CollationSorter_H_ */

==> jc-1.4.6.tar.gz: java/text/RuleBasedCollator__24CollationSorter.h <==
// final class java.text.RuleBasedCollator$CollationSorter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c548fa6aa0210e9c java_text_RuleBasedCollator__24CollationSorter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_RuleBasedCollator__24CollationSorter_H_
#define _JC_java_text_RuleBasedCollator__24CollationSorter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$sub_refs	_jc_java_text_RuleBasedCollator__24CollationSorter$sub_refs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$sub_nonrefs	_jc_java_text_RuleBasedCollator__24CollationSorter$sub_nonrefs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$refs	_jc_java_text_RuleBasedCollator__24CollationSorter$refs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$nonrefs	_jc_java_text_RuleBasedCollator__24CollationSorter$nonrefs;
typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$object	_jc_java_text_RuleBasedCollator__24CollationSorter$object;

typedef struct _jc_java_text_RuleBasedCollator__24CollationSorter$fields_struct	_jc_java_text_RuleBasedCollator__24CollationSorter$fields_struct;
typedef const struct _jc_java_text_RuleBasedCollator__24CollationSorter$vmethods	_jc_java_text_RuleBasedCollator__24CollationSorter$vmethods;
typedef const struct _jc_java_text_RuleBasedCollator__24CollationSorter$vtable	_jc_java_text_RuleBasedCollator__24CollationSorter$vtable;
typedef const struct _jc_java_text_RuleBasedCollator__24CollationSorter$vtype	_jc_java_text_RuleBasedCollator__24CollationSorter$vtype;

// Class fields structure
struct _jc_java_text_RuleBasedCollator__24CollationSorter$fields_struct {
	jint	EQUAL;
	jint	GREATERP;
	jint	GREATERS;
	jint	GREATERT;
	jint	INVERSE__5fSECONDARY;
	jint	RESET;
};
extern _jc_java_text_RuleBasedCollator__24CollationSorter$fields_struct _jc_java_text_RuleBasedCollator__24CollationSorter$class_fields;

// Constructors
extern void _jc_java_text_RuleBasedCollator__24CollationSorter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_text_RuleBasedCollator__24CollationSorter$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_text_RuleBasedCollator__24CollationSorter$vmethods {
};

// Vtable
struct _jc_java_text_RuleBasedCollator__24CollationSorter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_RuleBasedCollator__24CollationSorter$vmethods	java_text_RuleBasedCollator__24CollationSorter;
};

// Vtype
struct _jc_java_text_RuleBasedCollator__24CollationSorter$vtype {
	_jc_type			type;
	_jc_java_text_RuleBasedCollator__24CollationSorter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_RuleBasedCollator__24CollationSorter$sub_refs {
	struct _jc_java_lang_String$object	*textElement;
	struct _jc_java_lang_String$object	*expansionOrdering;
};

// Reference instance fields (object)
struct _jc_java_text_RuleBasedCollator__24CollationSorter$refs {
    _jc_java_text_RuleBasedCollator__24CollationSorter$sub_refs	java_text_RuleBasedCollator__24CollationSorter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_RuleBasedCollator__24CollationSorter$sub_nonrefs {
	jint	comparisonType;
	jint	hashText;
	jint	offset;
	jboolean	ignore;
};

// Non-reference instance fields (object)
struct _jc_java_text_RuleBasedCollator__24CollationSorter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_RuleBasedCollator__24CollationSorter$sub_nonrefs	java_text_RuleBasedCollator__24CollationSorter;
};

// Object instance structure
struct _jc_java_text_RuleBasedCollator__24CollationSorter$object {
	_jc_java_text_RuleBasedCollator__24CollationSorter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_RuleBasedCollator__24CollationSorter$vtype	*vtype;
	_jc_java_text_RuleBasedCollator__24CollationSorter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_RuleBasedCollator__24CollationSorter$vtype _jc_java_text_RuleBasedCollator__24CollationSorter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_RuleBasedCollator__24CollationSorter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_RuleBasedCollator__24CollationSorter$class_object;

#endif	/* _JC_java_text_RuleBasedCollator__24CollationSorter_H_ */
